@@ -10,7 +10,7 @@ use Bio::Grep::Backend::BackendI;
 
 use base 'Bio::Grep::Backend::Agrep';
 
-use version; our $VERSION = qv('0.8.4');
+use version; our $VERSION = qv('0.8.5');
 
 sub new {
     my $self = shift;
@@ -229,9 +229,10 @@ See L<Bio::Grep::Backend::BackendI> for inherited methods.
 
 =item C<Bio::Grep::Backend::RE-E<gt>new()>
 
-This function constructs an RE back-end object
+This method constructs a RE back-end object and should not used directly.  
+Rather, a back-end should be constructed by the main class L<Bio::Grep>:
 
-   my $sbe = Bio::Grep::Backend::RE->new();
+  my $sbe = Bio::Grep->new('RE');
 
 =item C<$sbe-E<gt>available_sort_modes()>
 
